function [color_gammapeak, grating_gammapeak] = FOOOFpipeline( obj, datIn, filenamepart )
%FOOOFpipeline Selects color and grating data, pipes it to FOOOF, returns
%gamma peaks for color and grating trials. Obj is a @Beamformer object,
%datIn is the data the pipeline is run on (could be sensor- or
%source-data). Filenampart is a string that will be added to the file name.
%Helpful if we're doing multiple fits per subjet, ie on the source- vs.
%sensor-level

conf = [];
colTrialNrs = obj.subject.behavior.trialNr(...
    strcmp(obj.subject.behavior.stimType, 'color'));
conf.trials = ismember(datIn.trialinfo, colTrialNrs);
fooofData = ft_selectdata(conf, datIn);
color_gammapeak = findGammaPeakFOOOF(obj.cfg, ...
    obj.subject, fooofData, [filenamepart '_color']);

if isnan(color_gammapeak)
    color_gammapeak = ...
        obj.cfg.gammapeak.fallback;
end

conf = [];
graTrialNrs = obj.subject.behavior.trialNr(...
    strcmp(obj.subject.behavior.stimType, 'grating'));
conf.trials = ismember(datIn.trialinfo, graTrialNrs);
fooofData = ft_selectdata(conf, datIn);
grating_gammapeak = findGammaPeakFOOOF(obj.cfg, ...
    obj.subject, fooofData, [filenamepart '_grating']);
if isnan(grating_gammapeak)
    grating_gammapeak = ...
        obj.cfg.gammapeak.fallback;
end

end

