function makeHCPsurfplots(obj, left_hem, right_hem, atlas)
% MAKEHCPSURFPLOTS Subfunction of @Beamformer. Create plots of the
% individual cortex surface & HCP parcellation, the headmodel and the
% gradiometers, save them in the plot folder.

grad = obj.data.grad;
headmodel = obj.headmodel;

% Clean up HCP atlas - merge left and right labels, give a random color per
% label, set NaN labeled vertices to grey.
atlas.corticalareas_dil_final_final_areas_group_colors = mod(...
    atlas.corticalareas_dil_final_final_areas_group_colors-1, 180) +1;

atlas.corticalareas_dil_final_final_areas_group_colors(...
    isnan(atlas.corticalareas_dil_final_final_areas_group_colors)) = ...
    max(atlas.corticalareas_dil_final_final_areas_group_colors) +1;

% We always want the same colors for the labels, so set seed.
rng(0190666666, 'twister'); 
colors = rand(3, 180);
rng default
colors(:, 181) = [128 128 128];

left = atlas.brainstructure == 1;
right = atlas.brainstructure == 2;
atlasL = atlas.corticalareas_dil_final_final_areas_group_colors(left);
atlasR = atlas.corticalareas_dil_final_final_areas_group_colors(right);

figure('units', 'centimeters','position', [1 1 30 18], 'Visible', 'off',...
    'Color', 'w');
subplot(1,2,1)
hold on
ft_plot_headmodel(headmodel, 'facecolor', 'cortex', 'edgecolor',...
    'none', 'facealpha', 0.4);
ft_plot_headshape(left_hem, 'vertexcolor', colors(:,atlasL)')
ft_plot_headshape(right_hem, 'vertexcolor', colors(:,atlasR)')
ft_plot_sens(grad, 'style', '*b', 'coil', false);
camlight;
view([86 30])

subplot(1,2,2)
hold on
ft_plot_headmodel(headmodel, 'facecolor', 'cortex', 'edgecolor',...
    'none', 'facealpha', 0.4);
ft_plot_headshape(left_hem, 'vertexcolor', colors(:,atlasL)')
ft_plot_headshape(right_hem, 'vertexcolor', colors(:,atlasR)')
ft_plot_sens(grad, 'style', '*b', 'coil', false);
camlight;
view([-200 0])

export_fig(obj.subject.saveplots.HCPsourcemodel,...
    '-png','-q101','-r400');
end

