function subjectDICSPlot( obj, sourcedata )
% subjectDICSPlot is a subfunction of @Beamformer. It takes the output of
% DICS beamforming and creates a plot, either volumetrically (for grid
% coordinate systems) or on the 32f_fs_LR (for HCP-based coordinate
% systems).

disp('Creating individual DICS source plot.')
switch obj.cfg.general.HCP_or_grid_sources
    case 'grid'
        % interpolate sources on MNI-normalised MRI (step 5)
        sourcedata.pos = obj.mni_coordinates;
        norm_mri = ft_volumenormalise([], obj.mri);
        conf = [];
        conf.parameter             = 'avg.pow';
        sourcedata_interpo = ft_sourceinterpolate(conf, ...
            sourcedata , norm_mri);
        
        % plot dics results
        atlas = ft_read_atlas(obj.cfg.beam.mask.atlasname);
        conf               = [];
        conf.method        = 'ortho';
        conf.funparameter  = 'pow';
        conf.maskparameter = conf.funparameter;
        conf.atlas         = atlas;
        conf.visible       = 'on';
        conf.opacitylim    = 'zeromax';
        conf.slicedim = 2;
        ft_sourceplot(conf, sourcedata_interpo);
        
    case 'HCP'
        disp(['Creating HCP-Atlas-based cortical midsurface '...
            'sourcemodel.']);
        createHCPSourcemodel(obj);
    otherwise
        error(['Invalid source model type requested. '...
            'Must be ''HCP'' or ''grid''.'])
end


end

