function [ cfg ] = fillGroupConfigs( obj, basepath )
%GROUPSETTINGS Summary of this function goes here
%   Detailed explanation goes here


%% General
% Run on SLURM or on the interactive node?
cfg.general.use_slurm = true;
cfg.general.rerunAnalyses = false; % should per-subject analyses be rerun 
% by default? If not, results from their last run are loaded from disc.

% Use github version of fieldtrip instead of the ESI internal one?
cfg.general.useGithub = true;

%% Paths
cfg.paths.base = basepath;
cfg.paths.analysis = fullfile(basepath, 'Analysis');
cfg.paths.data = fullfile(basepath, 'Data');
cfg.paths.code = fullfile(cfg.paths.analysis, 'Code');
cfg.paths.plot = fullfile(cfg.paths.analysis, 'Plots');
cfg.paths.util = fullfile(cfg.paths.code, 'Utility');
cfg.paths.result = fullfile(cfg.paths.analysis, 'Results');
cfg.paths.freqData = fullfile(cfg.paths.data, 'Preprocessed', ...
    'freqs');
cfg.paths.ERFdata = fullfile(cfg.paths.data, 'Preprocessed', ...
    'ERFs');

%% Plot of gamma power over all trials
cfg.trialplot.span = 11; % Span of moving mean and CIs
cfg.trialplot.demean = true; % Demean within participant
cfg.trialplot.zscore = false; % Z-Score within participant

%% General plotting settings
cfg.plots.size = [0 0 5 4];

%% ERF plots
cfg.erfplot.scaling = 1;
cfg.erfplot.ERFcomps = [0.057 0.094]; % make sure this corresponds to the setting in fillConfigs()

%% Plot of aligned gamma spectra over bins
cfg.spectplot.bins = 4;

%% HCP-based plots
hcp_folder = fullfile(basepath, 'Data', 'Freesurfed', 'HCP');
cfg.hcp.atlas = fullfile(hcp_folder, ['Q1-Q6_RelatedValidation210.'...
    'CorticalAreas_dil_Final_Final_Areas_Group_Colors.32k_fs_LR.dlabel.nii']);
plot_template = 'very_inflated';
if strcmp(plot_template, 'flat') || strcmp(plot_template, 'sphere')
    cfg.hcp.plot_template = {...
        [hcp_folder '/Q1-Q6_RelatedValidation210.L.' plot_template ...
        '.32k_fs_LR.surf.gii'],...
        [hcp_folder '/Q1-Q6_RelatedValidation210.R.' plot_template ...
        '.32k_fs_LR.surf.gii']};
else
    cfg.hcp.plot_template = {...
        [hcp_folder '/Q1-Q6_RelatedValidation210.L.' plot_template ...
        '_MSMAll_2_d41_WRN_DeDrift.32k_fs_LR.surf.gii'],...
        [hcp_folder '/Q1-Q6_RelatedValidation210.R.' plot_template ...
        '_MSMAll_2_d41_WRN_DeDrift.32k_fs_LR.surf.gii']};
end
cfg.hcp.eccent = fullfile(hcp_folder, 'Retinotopy', ['S1200_7T_Retinotopy'...
    '181.Fit1_Eccentricity_MSMAll.32k_fs_LR.dscalar.nii']);
cfg.hcp.polAng = fullfile(hcp_folder, 'Retinotopy', ['S1200_7T_Retinotopy'...
    '181.Fit1_PolarAngle_MSMAll.32k_fs_LR.dscalar.nii']);

end

