function [] = gammaEnhancement (subject, cfg, data)
%GAMMAENHANCEMENT   applies LCMV filters on dipoles of interest. Uses
%multiplyTrialsWeights.m and individualGammaPeak.m.

%% Preparation
ESIload(fullfile(subject.prepoc_data, 'subject'));

% identify dipoles of interest in filter (step 1)
DOI = cfg.doi;
gammaDOI = cell(length(DOI),1);
for iDOI = 1:length(DOI)
    this_dipole  = DOI{1,iDOI};
    dipole_pos   = subject.sources.(this_dipole).pos;
    x            = find(subject.dipoles.mni_pos(:,1) == (dipole_pos(1)));
    y            = find(subject.dipoles.mni_pos(:,2) == (dipole_pos(2)));
    z            = find(subject.dipoles.mni_pos(:,3) == (dipole_pos(3)));
    gammaDOI{iDOI,1} = intersect(x,y);
    subject.sources.(this_dipole).gammaDOI = intersect(gammaDOI{iDOI,1},z);
end

% cut out ERF (step 2)
data      = ft_selectdata (cfg.chan, data);
data_base = ft_redefinetrial(cfg.erfbase, data);
data_stim = ft_redefinetrial(cfg.erfstim, data);

%% Run FFTs and apply weights

nTrials                     = size(data.trialinfo,1);
freqsteps                   = cfg.bandwidth * (1/cfg.resolution);
spectrumResults             = cell(length(DOI),1);
results                     = cell(length(DOI),1);
%nStim                       = 
 
for iDOI = 1:length(DOI) % for all dipoles of interest
    
    this_dipole  = DOI{1,iDOI};
    this_dipole  = subject.sources.(this_dipole).gammaDOI;
    
    spectrumResults{iDOI,1}.label       = cfg.doi{iDOI};
    spectrumResults{iDOI,1}.effect      = NaN(nTrials,freqsteps);
    spectrumResults{iDOI,1}.freqs       = NaN(nTrials,freqsteps);

    % find individual gamma peak (step 3)
    peak = individualGammaPeak(cfg,subject,data_stim,this_dipole);
    peak = round(peak);
    subject.sources.(DOI{1,iDOI}).peak = peak;
    
    % construct dipole_base and dipole_stim (step 4)
    dipole_base.trial      = multiplyTrialsWeights(data_base.trial, ...
                             subject.dipoles.filters{this_dipole});
    dipole_base.time       = data_base.time;
    dipole_base.sampleinfo = data_base.sampleinfo;
    dipole_base.label      = sprintfc([strcat('Dipole_',...
                             num2str(this_dipole)) '_%d'], 1:3);
    
    dipole_stim.trial      = multiplyTrialsWeights(data_stim.trial, ...
                             subject.dipoles.filters{this_dipole});
    dipole_stim.time       = data_stim.time;
    dipole_stim.sampleinfo = data_stim.sampleinfo;
    dipole_stim.label      = sprintfc([strcat('Dipole_',...
                             num2str(this_dipole)) '_%d'], 1:3);
    
    % Do frequency analysis (step 5)
    if cfg.stimspec_gamma
        cfg.freq.foi  = ((min(peak)-cfg.bandwidth/2):cfg.resolution:...
                        (max(peak)+cfg.bandwidth/2));
    else
        cfg.freq.foi  = (peak-(cfg.bandwidth/2):cfg.resolution:...
                        peak+(cfg.bandwidth/2));
    end                         
    freq_base         = ft_freqanalysis(cfg.freq, dipole_base);
    freq_stim         = ft_freqanalysis(cfg.freq, dipole_stim);
    
    % calculate effectscore (step 6)
    meanfreq_baseInd  = squeeze(mean(freq_base.powspctrm,2));
    meanfreq_stim     = squeeze(mean(freq_stim.powspctrm,2));
    meanfreq_base     = squeeze(mean(meanfreq_baseInd,1));
    effectscore = bsxfun(@rdivide, meanfreq_stim, meanfreq_base(1,:));
    
    % fill results structure (step 7)
    if cfg.stimspec_gamma
        for iStim = 1:nStim
            [~, stims]  = unique(stim_type);
            stims = sort(stims);
            trials_stim = find(stim_type == stim_type(stims(iStim)));
        
            % get the indices of the stimulus-specific frequency band
            iLower = (peak(iStim) - (bandwidth/2));
            iUpper = (peak(iStim) + (bandwidth/2));
            
            iEffect   = effectscore(trials_stim, iLower:iUpper);
            iFreqs    = peak(iStim)-(cfg.bandwidth/2) :...
                        cfg.resolution : peak(iStim)+(cfg.bandwidth/2);
            spectrumResults.effect(trials_stim,:)= iEffect;
            spectrumResults.freqs(trials_stim,:) = repmat(iFreqs,trials_stim);
        end
    else
       spectrumResults.effect = effectscore;
       spectrumResults.freqs  = repmat((peak-(cfg.bandwidth/2):cfg.resolution:...
                                peak+(cfg.bandwidth/2)),nTrials);
    end
    
    % fill results table (step 9)
    trial_nr          = data.trialinfo;
    logtrial_nr       = log(trial_nr);
    trial_pb          = subject.behav_results.stimNr(trial_nr);
    logtrial_pb       = log(trial_pb);
    stim_type         = subject.behav_results.orientation(trial_nr);
    band_width        = cfg.bandwidth;
    resolution        = cfg.resolution;
    band_lower        = spectrumResults.freqs(1,:);
    band_higher       = spectrumResults.freqs(end,:);
    effect            = squeeze(mean((resultsFFT.effect),2));
    log_effect        = log(results);
    
    results{iDOI}     = table(trial_nr, trial_pb, logtrial_nr, logtrial_pb,...
                        stim_type, band_width, resolution, band_lower,...
                        band_higher, effect, log_effect);
end

%% Plot and save results

plotBinnedResults (subject,results,spectrumResults)

ESIsave(fullfile(subject.prepoc_data,'results'),'results');
ESIsave(fullfile(subject.prepoc_data,'spectrumResults'),'spectrumResults');

end