function [peak] = individualGammaPeak (cfg, subject, data, iDipole)
%INDIVIDUALGAMMAPEAK  Determines subject specific gamma peak using
%findGammaPeak.m for a given dipole. The frequency spectrum ranges from 35
%to 95 Hz. Can be determined per stimulus or over all trials.

% FIND STIMULUS SPECIFIC GAMMA 

if cfg.stimspec_gamma
    stim_type = subject.behav_results.orientation(:,1);
    stim_type = stim_type(data.trialinfo(:,1), 1);
    nStim     = length(unique(stim_type));
    peak      = NaN(nStim);
    
    for iStim = 1:nStim
        [~, stims]      = unique(stim_type);
        stims           = sort(stims);
        trials_stim     = find(stim_type == stim_type(stims(iStim)));
        cfg.stim.trial  = trials_stim;
        data.trial = ft_redefinetrial(cfg.stim, data);
        
        % prepare freq analysis
        dipole.trial      = multiplyTrialsWeights(data.trial, ...
                            subject.dipoles.filters{iDipole});
        dipole.time       = data.time;
        dipole.sampleinfo = data.sampleinfo;
        dipole.label      = sprintfc([strcat('Dipole_',...
                            num2str(iDipole)) '_%d'],1:3);
        
        % determine frequency band
        cfg.freqpsd.foi = 30:0.5:100;
        
        % run freq analysis
        freq = ft_freqanalysis(cfg.freqpsd, dipole);
        
        % find gamma peak
        peak(iStim) = findGammaPeak(cfg.gammapeak,subject,freq.freq,...
                                    freq.powspctrm);
    end

% FIND GAMMA PEAK FOR ALL STIMULI
    
else % prepare freq analysis 
    dipole.trial      = multiplyTrialsWeights(data.trial, ...
                        subject.dipoles.filters{iDipole});
    dipole.time       = data.time;
    dipole.sampleinfo = data.sampleinfo;
    dipole.label      = sprintfc([strcat('Dipole_',...
                        num2str(iDipole)) '_%d'],1:3);
    
    % determine frequency band
    cfg.freqpsd.foi = 30:0.5:100;
    
    % run freq analysis
    freq = ft_freqanalysis(cfg.freqpsd, dipole);
    
    % find gamma peak
    peak = findGammaPeak(cfg.gammapeak,subject,freq.freq,freq.powspctrm);
end

end
