function [] = plotBinnedResults(subject, results, spectrumResults)
% PLOTBINNEDRESULTS   Plots results that are calculated using
% gammaEnhancement.m. 
%
% Input:
% Subject         = subject structure as saved using beamform.m and modified
%                   using gammaEnhancement.m
% Results         = results table as created using gammaEnhancement.m
% SepctrumResults = structure containing frequency and power information
%                   for one dipole over all trials, as created using 
%                   gammaEnhancement.m
%
% Output:
% Plots are saved using subject specific path.

%% Create Bins

stim_type    = subject.behav_results.orientation(:,1);
stim_type    = stim_type(data.trialinfo(:,1), 1);
nStim        = length(unique(stim_type));
freq         = spectrumResults.freqs(1,:);
stim         = cell(nStim,1);
effectbinned = cell(nStim,1);

for iStim = 1:nStim
    [~, stims]  = unique(stim_type);
    stims = sort(stims);
    trials_stim = find(stim_type == stim_type(stims(iStim)));
    stim{iStim,1} = spectrumResults.effect(trials_stim);
end


for iStim = 1:length(stim)
    bins = round(linspace(1,length(stim{iStim,1}),cfg.bins));  
    for iBin = 1:(length(bins1)-1)
        effectbinned{iStim,1}(iBin,:) = mean((stim{iStim,1}(bins(iBin):...
            bins(iBin+1),:)),1);
    end
end

saveas 

%% Plot overall effect 

plot (results.logeffect)
overallmean = mean(results.logeffect);
refline(0,overallmean)
for iStim = 1:(nStim-1)
   line([stims(iStim+1) stims(iStim+1)], get(gca,'ylim'))
   hold on
end

saveas(gcf, strcat(subject.saveplots.enhance,'_trials'),'png')

%% Plot binned results

figure()
for iStim=1:nStim
    iEffect = effectbinned{iStim,1};
    subplot(2,2,iStim);
    set(gca, 'ColorOrder', jet(8));
    set(gca, 'DefaultLineLineWidth', 3);
    hold all
    for iBin=1:(cfg.bins-1)
        plot(freq,iEffect(iBin,:));
        hold on
    end
    hold on
end
legend('Bin 1','Bin 2','Bin 3','Bin 4','Bin 5','Bin 6','Bin 7')

saveas(gcf, strcat(subject.saveplots.enhance,'_stim'),'png')

end
