savePlots = false;

allMonitors = {'MITSUBISHI_DV_VS10162', 'ProPixx', 'LG_32GK',...
    'Samsung_2233RZ', 'Sony_PFM', 'ACER_AL1712'};

for iMonitor = 1:length(allMonitors)
    monitor = allMonitors{iMonitor};
    [colors, fundamentals] = load_default_spectra(monitor, ...
        'StockMannSharpe2010_10deg');
    
    allRGBs = [rgbCoords; 102 102 102];
    iLAB = NaN(size(allRGBs,1),3);
    iRGB = NaN(size(allRGBs,1),3);
    for iStim = 1:size(allRGBs,1)
        iRGB(iStim,:) = lin2rgb(allRGBs(iStim,:)./255);
        iLAB(iStim,:) = rgb2lab(iRGB(iStim,:));
    end
    
    scatter(iLAB(:,2), iLAB(:,3), 300, iRGB, 'filled')
    xlabel('a')
    ylabel('b')
    
    scatter(ones(9,1), iLAB(:,1), 300, iRGB, 'filled')
    
    %% revert the plot - show equidistant LAB colors in DKL
    baseLum = 60;
    bd = 30;
    od = sqrt(bd^2/2);
    aCoord = [0, bd, od, 0, -od, -bd, -od, 0, od]';
    bCoord = [0, 0, od, bd, od, 0, -od, -bd, -od]';
    tLAB = [repmat(baseLum,9,1), aCoord, bCoord];
    
    baseLMS = rgb2lms(rgb2lin(lab2rgb([baseLum,0,0])), colors, fundamentals);
    
    for iCol = 1:size(tLAB,1)
        iRGB(iCol,:) = rgb2lin(lab2rgb(tLAB(iCol,:)));
        iLMS = rgb2lms(iRGB(iCol,:), colors, fundamentals);
        iDKL(iCol,:) = lms2dkl(iLMS, baseLMS);
    end
    
    % Differences in luminance
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    scatter(tLAB(:,2), tLAB(:,1), 50, ...
        lin2rgb(iRGB), 'filled')
    axis equal
    xlabel('a*')
    ylabel('L*')
    iLim = [xlim; ylim];
    toAdd = 0.1*(max(iLim')-min(iLim'));
    xlim([iLim(1,1) - toAdd(1), iLim(1,2) + toAdd(1)])
    ylim([iLim(2,1) - toAdd(2), iLim(2,2) + toAdd(2)])
    exportgraphics(fig, ['LABtoDKL1' '_' monitor '.pdf'])
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    scatter(iDKL(:,2), iDKL(:,1), 50, ...
        lin2rgb(iRGB), 'filled')
    xlabel('L-M')
    ylabel('L+M')
    iLim = [xlim; ylim];
    toAdd = 0.1*(max(iLim')-min(iLim'));
    xlim([iLim(1,1) - toAdd(1), iLim(1,2) + toAdd(1)])
    ylim([iLim(2,1) - toAdd(2), iLim(2,2) + toAdd(2)])
    if savePlots, exportgraphics(fig, ['LABtoDKL2' '_' monitor '.pdf']); end
    
    % Differences in color contrast
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    scatter(tLAB(:,2), tLAB(:,3).*-1, 50, ...
        lin2rgb(iRGB), 'filled')
    axis equal
    xlabel('a*')
    ylabel('b*')
    iLim = [xlim; ylim];
    toAdd = 0.1*(max(iLim')-min(iLim'));
    xlim([iLim(1,1) - toAdd(1), iLim(1,2) + toAdd(1)])
    ylim([iLim(2,1) - toAdd(2), iLim(2,2) + toAdd(2)])
    if savePlots, exportgraphics(fig, ['LABtoDKL3' '_' monitor '.pdf']); end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    scatter(iDKL(:,2), iDKL(:,3), 50, ...
        lin2rgb(iRGB), 'filled')
    xlabel('L-M')
    ylabel('S-(L+M)')
    iLim = [xlim; ylim];
    toAdd = 0.1*(max(iLim')-min(iLim'));
    xlim([iLim(1,1) - toAdd(1), iLim(1,2) + toAdd(1)])
    ylim([iLim(2,1) - toAdd(2), iLim(2,2) + toAdd(2)])
    if savePlots, exportgraphics(fig, ['LABtoDKL4' '_' monitor '.pdf']); end
%     
%     fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
%     scatter(iDKL(:,2), iDKL(:,3), ...
%         150*zscore(iDKL(:,1)) +240, ...
%         lin2rgb(iRGB), 'filled')
%     yline(0, ':')
%     xline(0, ':')
%     if savePlots, exportgraphics(fig, 'LABinDKLplot_LUM' '_' monitor '.pdf'); end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(iDKL(:,1), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB);
    box off
    ylabel('L+M')
    if savePlots, exportgraphics(fig, ['LABinDKLplot_LUMbar' '_' monitor '.pdf']); end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(sqrt(iDKL(:,2).^2 + iDKL(:,3).^2), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB);
    box off
    ylabel('Color contrast')
    if savePlots, exportgraphics(fig, ['LABinDKLplot_DISTbar' '_' monitor '.pdf']); end
    
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(abs(iDKL(2,2))-abs(iDKL(6,2)), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB([2],:));
    box off
    ylabel('L-M bias')
    if savePlots, exportgraphics(fig, ['LABinDKLplot_LMbar' '_' monitor '.pdf']); end
    biasLAB(iMonitor) = abs(iDKL(2,2))-abs(iDKL(6,2));

    
    tHUE = linspace(0, 1, 8);
    tHSV = [tHUE', ones(size(tHUE,2),2)];
    
    clear iRGB iLMS iDKL
    for iCol = 1:size(tHSV,1)
        iRGB(iCol,:) = rgb2lin(hsv2rgb(tHSV(iCol,:)));
        iLMS = rgb2lms(iRGB(iCol,:), colors, fundamentals);
        iDKL(iCol,:) = lms2dkl(iLMS, baseLMS);
    end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(iDKL(:,1), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB);
    box off
    ylabel('L+M')
    if savePlots, exportgraphics(fig, ['HSVinDKLplot_LUMbar' '_' monitor '.pdf']); end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(sqrt(iDKL(:,2).^2 + iDKL(:,3).^2), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB);
    box off
    ylabel('Color contrast')
    if savePlots, exportgraphics(fig, ['HSVinDKLplot_DISTbar' '_' monitor '.pdf']); end
    
    fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
    h = bar(abs(iDKL(2,2))-abs(iDKL(6,2)), 'FaceColor', 'flat', ...
        'EdgeColor', 'none');
    h.CData = lin2rgb(iRGB([2],:));
    box off
    ylabel('L-M bias')
    if savePlots, exportgraphics(fig, ['HSVinDKLplot_LMbar' '_' monitor '.pdf']); end
    biasHSV(iMonitor) = abs(iDKL(4,2))-abs(iDKL(8,2));

    %     

%     fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
%     scatter(iDKL(:,2), iDKL(:,3), ...
%         100*zscore(iDKL(:,1)) +225 + 100*zscore(sqrt(iDKL(:,2).^2 + iDKL(:,3).^2)), ...
%         lin2rgb(iRGB), 'filled')
%     yline(0, ':')
%     xline(0, ':')
%     if savePlots, exportgraphics(fig, 'LABinDKLplot_LUMplusDIST' '_' monitor '.pdf'); end
%     
%     
%     fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
%     scatter(iDKL(:,2), iDKL(:,3), [ 50;...
%         150*zscore(sqrt(iDKL(2:end,2).^2 + iDKL(2:end,3).^2))+205], ...
%         lin2rgb(iRGB), 'filled')
%     yline(0, ':')
%     xline(0, ':')
%     if savePlots, exportgraphics(fig, 'LABinDKLplot_DIST_grayAt50' '_' monitor '.pdf'); end
    
end
% Part below failed due to insufficient info in shirhatti & ray

% %% same for HSV show equidistant HSV colors in DKL
% xyy_x = [0.6448, 0.5707, 0.5248, 0.4935, 0.4708, 0.4536, 0.4401, 0.4272,...
%     0.4127, 0.3961, 0.3768, 0.3544, 0.3277, 0.3081, 0.2927, 0.2803,...
%     0.2699, 0.2612, 0.2538, 0.2463, 0.237, 0.2253, 0.21, 0.1895,...
%     0.1602, 0.2108, 0.2517, 0.2855, 0.3139, 0.3382, 0.3591, 0.3808,...
%     0.4077, 0.4421, 0.4876, 0.5509]';
% xyy_y = [0.3307, 0.3954, 0.4354, 0.4628, 0.4826, 0.4976, 0.5094, 0.5206,...
%     0.5333, 0.5478, 0.5646, 0.5843, 0.6076, 0.544, 0.4938, 0.4531,...
%     0.4195, 0.3912, 0.367, 0.3424, 0.3121, 0.2739, 0.2244, 0.1575,...
%     0.062, 0.09, 0.1127, 0.1315, 0.1472, 0.1607, 0.1723, 0.1843, 0.1992,...
%     0.2183, 0.2436, 0.2786]';
% xyy_Y = [26.004, 40.56, 55.08, 69.576, 84.06, 98.532, 113.00, 108.68,...
%     104.35, 100.02, 95.688, 91.356, 87, 88.176, 89.34, 90.504, 91.668,...
%     92.832, 93.996, 79.524, 65.052, 50.568, 36.072, 21.552, 6.996,...
%     11.352, 15.684, 20.016, 24.348, 28.668, 33, 31.836, 30.672, 29.508,...
%     28.344, 27.168]';
%
% xyy = [xyy_x xyy_y xyy_Y];
% xyz = xyYToXYZ(xyy);
%
% tXYZ = [(xyy_x./xyy_y).*xyy_Y, xyy_Y, ...
%     (xyy_Y./xyy_y).*(1-xyy_x-xyy_y)];
%
% tHUE = [0:10:350]./360;
% tHSV = [tHUE', ones(size(tHUE,2),2)];
%
% baseLMS = rgb2lms([0.4 0.4 0.4]);
%
% iRGB = NaN(size(tXYZ,1),3);
% iDKL = NaN(size(tXYZ,1),3);
%
% for iCol = 1:size(tXYZ,1)
%    iRGB(iCol,:) = rgb2lin(xyz2rgb(tXYZ(iCol,:)));
%    iLMS = rgb2lms(iRGB(iCol,:));
%    iDKL(iCol,:) = lms2dkl(iLMS, baseLMS);
% end
%
% fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
% scatter(iDKL(:,2), iDKL(:,3), ...
%     150*zscore(iDKL(:,1)) +220, ...
%     lin2rgb(iRGB), 'filled')
% yline(0, ':')
% xline(0, ':')
% exportgraphics(fig, 'HSVinDKLplot_LUM' '_' monitor '.pdf')
%
% fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
% h = bar(iDKL(:,1), 'FaceColor', 'flat', ...
%     'EdgeColor', 'none');
% h.CData = lin2rgb(iRGB);
% box off
% ylabel('L+M')
% exportgraphics(fig, 'HSVinDKLplot_LUMbar' '_' monitor '.pdf')
%
% fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
% h = bar(sqrt(iDKL(:,2).^2 + iDKL(:,3).^2), 'FaceColor', 'flat', ...
%     'EdgeColor', 'none');
% h.CData = lin2rgb(iRGB);
% box off
% ylabel('Color contrast')
% exportgraphics(fig, 'HSVinDKLplot_DISTbar' '_' monitor '.pdf')
%
% fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
% scatter(iDKL(:,2), iDKL(:,3), ...
%     100*zscore(iDKL(:,1)) +240 + 100*zscore(sqrt(iDKL(:,2).^2 + iDKL(:,3).^2)), ...
%     lin2rgb(iRGB), 'filled')
% yline(0, ':')
% xline(0, ':')
% exportgraphics(fig, 'HSVinDKLplot_LUMplusDIST' '_' monitor '.pdf')
%
%
% fig = figure('Unit', 'centimeter', 'Position', [0 0 4 4]);
% scatter(iDKL(:,2), iDKL(:,3), [ 50;...
%     150*zscore(sqrt(iDKL(2:end,2).^2 + iDKL(2:end,3).^2))+255], ...
%     lin2rgb(iRGB), 'filled')
% yline(0, ':')
% xline(0, ':')
% exportgraphics(fig, 'LABinDKLplot_DIST_grayAt50' '_' monitor '.pdf')
