function [cfg] = ems_plot_eyeposition(cfg)
% uses detection algorithim from Engbert, R. & Kliegl, R. (2002)
% computes a different threshold relative to noise for each trial
% seperate threshold for vertical and horizontal velocities

addpath('~/microsaccades_CB/scripts/')

if ~exist('cfg','var'); cfg = []; end
if ~isfield(cfg, 'filename')
    [file, fold] = uigetfile(...
        {'*.ems;*bhvems*', 'Eye file'}, ...
        'Pick ems file for eyeposition analysis',...
        '~/rew_analysis/bhv/');
    if ~ischar(file); cfg = []; return; end
    cfg.filename = [fold,file];
end
if ~isfield(cfg, 'latency')
    cfg.latency = [0.5 1.2];
end

%% read bhv or ems

ems = load(cfg.filename, '-mat');
ems = ems.ems;

%% prepare data

cfgIn = [];
cfgIn.toilim = cfg.latency;
ems = ft_redefinetrial(cfgIn, ems);

%% setup plotting

conditions = {'hh','lh','hl','ll'};
col = {[0 0 1],[0 0.5 0],[1 0 1],[1 0 0]};

%% store locations
win = [-1 1];
nBins = 100;
binEdge = linspace(win(1),win(2),nBins+1);

for iRew = 1:4
    rewTrls = find(ems.trialinfo(:,12) == iRew);
    eye{iRew} = 0;
    for iTrl = rewTrls(:)'
        xy = ems.trial{iTrl}';
        
        [~,xyInd] = histc(xy,binEdge);
        
        % remove positions outside win and remove final bin
        rmInd = sum(xyInd==0 | xyInd==length(binEdge),2);
        xyInd(rmInd >= 1,:) = [];
        
        yxInd = xyInd(:,[2,1]); % switch
        
        % make 2D counts of eye position
        eye{iRew} = eye{iRew} + accumarray(yxInd, 1, [nBins, nBins]);
    end
    eye{iRew} = eye{iRew}./length(rewTrls);
    normEye = (eye{iRew}-min(eye{iRew}(:)))./(max(eye{iRew}(:)) - min(eye{iRew}(:)));
    %eyeCol{iRew} = repmat(,[1 1 3]);
    %colour = repmat(reshape(col{iRew}
    eyeCol{iRew} = bsxfun(@times,normEye,reshape(col{iRew},[1,1,3]));
end

%% plotting settings
[~, basename] = fileparts(cfg.filename);
[~, basename] = fileparts(basename);
savename = ['/mnt/gs/home/shapcottk/rew_analysis/images/emsbhv/' basename '_'];

%% plot
clim = [0 max(max(cat(2,eye{:})))];

h = figure('Color','white', 'Position', [0 0 850 800]);
tmp = gray;
colormap(tmp(end:-1:1,:))
for iRew = 1:4
    %colormap(bsxfun(@times,tmp,col{iRew}))%not per axis
    subplot(2,2,iRew)
    imagesc(binEdge,binEdge,eye{iRew})%,'AlphaData',ones([nBins,nBins,3])*-0.5)
    set(gca,'Clim',clim)
    grid on
    axis equal
    %hold on
    set(gca,'YDir','normal')
    xlabel(conditions{iRew})
    title(sprintf('Eye positions %0.1f-%0.1fs', cfg.latency))
end

export_fig(h, [savename 'fixPos_image.pdf'])

%% plot contour

contours = linspace(clim(1),clim(2),5);

h = figure('Color','white','Position', [0 0 1100 450]);

for iRew = 1:4
    if iRew == 1 || iRew == 4
        subplot(1,2,1)
    else
        subplot(1,2,2)
    end
    contour(binEdge(1:end-1),binEdge(1:end-1),eye{iRew},contours(1:end-1),...
        'Color',col{iRew}, 'LineWidth', 5)
    hold on
    grid on
    %axis equal
    set(gca,'YDir','normal')
    %xlabel(conditions{iRew})
    title(sprintf('Eye positions %0.1f-%0.1fs', cfg.latency))
    
    if iRew == 1 || iRew == 4
        legend(conditions([1,4]))
    else
        legend(conditions([2,3]))
    end
end
export_fig(h, [savename 'fixPos_contour.pdf'])

end

%% subfunctions
