function v = vecvel(x,SAMPLING,TYPE)
%--------------------------------------------------------------------
%  FUNCTION vecvel.m
%  (Version 1.1, 25 FEB 01)
%  edited KS 22 MAY 18- TYPE 3
%--------------------------------------------------------------------
% INPUT
%   x(1:N,1)     raw data, x-component of the time series
%   x(1:N,2)     raw data, y-component of the time series
%   SAMPLING     sampling rate (e.g., 250 Hz)
%   TYPE         velocity type (1(fast) or 2(slow))
% OUTPUT
%   v(1:N,1)     x-component
%   v(1:N,2)     y-component
%-------------------------------------------------------------
if ~exist('TYPE', 'var'); TYPE = 2; end
N = length(x);      % length of the time series
v = zeros(N,2);
for k=2:N-1
    switch TYPE
        case 1
            % fast velocity
            v(k,1:2) = SAMPLING/2*[x(k+1,1)-x(k-1,1) x(k+1,2)-x(k-1,2)];
        case 2
            % slow velocity
            if k>=3 & k<=N-2
                %   double smoothing
                v(k,1:2) = SAMPLING/6*[x(k+2,1)+x(k+1,1)-x(k-1,1)-x(k-2,1) x(k+2,2)+x(k+1,2)-x(k-1,2)-x(k-2,2)];
            end
        case 3
            % even slower vel (for high sampling rates)
            if k>=4 & k<=N-3
                % triple smoothing
                v(k,1) = SAMPLING/12*(x(k+3,1)+x(k+2,1)+x(k+1,1) - x(k-1,1)-x(k-2,1)-x(k-3,1));
                v(k,2) = SAMPLING/12*(x(k+3,2)+x(k+2,2)+x(k+1,2) - x(k-1,2)-x(k-2,2)-x(k-3,2));
            end
    end
end

% replace start and end zeros with nearby value
try
v(1:TYPE,:) = repmat(v(TYPE+1,:),TYPE,1);
v(end-TYPE+1:end,:) = repmat(v(TYPE+1,:),TYPE,1);
catch
    warning('Empty trial filled with zeroes.');
    v = zeros(size(v));
end
end
