%eyetracker delay

addpath /mnt/hpx/opt/fieldtrip_github;
ft_defaults;

cd('/mnt/cs/projects/HMgammaRepSpecif/Data/Equipment testing/');

%read in eye tracker left x and VEOG channels
cfg.dataset = 'testeye_ESI-HMgammaRepSpecif_20180614_01.ds';
cfg.channel = {'UADC009','EEG058'};
cfg.continuous = 'yes';
cfg.preproc.demean = 'yes';
data = ft_preprocessing(cfg);

% % view data to identify kernel
cfg.channel = {'UADC009'};
cfg = ft_databrowser(cfg,data);

%get raw data values for one blink onset and blink offset
chanETR = data.trial{1,1}(2,:);

%sampleLocBeg = 1830:1980;
sampleLocBeg = 47150:47300; %Equipment Testing
% sampleLocBeg = 6300:6450; %Data 006
sampleBeg = chanETR (sampleLocBeg);
peakSample = find(sampleBeg==max(sampleBeg));
sampleWindowBeg = 1:(2*peakSample-1);

%sampleLocEnd = 2050:2200;
sampleLocEnd = 47500:47650; %Equipment Testing
% sampleLocEnd = 6450:6600; %Data 006
sampleEnd = chanETR (sampleLocEnd);
peakSample = find(sampleEnd==max(sampleEnd));
sampleWindowEnd = 1:(2*peakSample-1);

sampleKernelBeg = sampleBeg(sampleWindowBeg);
sampleKernelBeg = sampleKernelBeg - mean(sampleKernelBeg);
sampleKernelBeg = fliplr(sampleKernelBeg);

sampleKernelEnd = sampleEnd(sampleWindowEnd);
sampleKernelEnd = sampleKernelEnd - mean(sampleKernelEnd);
sampleKernelEnd = fliplr(sampleKernelEnd);

figure()
plot(sampleKernelEnd);

%% Create mean kernel

%convolve ETR data with Sample blink
convSampleBeg = conv(chanETR,sampleKernelBeg,'same');
convSampleEnd = conv(chanETR,sampleKernelEnd,'same');

%extract samples of eyetracker data to create mean blink for kernel
[~,fitsTimeBeg] = findpeaks(convSampleBeg,'MinPeakHeight',500,...
                  'MinPeakDistance',100);
fitsTimeBeg = fitsTimeBeg(2:end-1);

[~,fitsTimeEnd] = findpeaks(convSampleEnd,'MinPeakHeight',500,...
                  'MinPeakDistance',100);
fitsTimeEnd = fitsTimeEnd(2:end-1);

%define window
nSampleKernel = 151;
windowsBeg = NaN(size(fitsTimeBeg,2),nSampleKernel);
windowsEnd = NaN(size(fitsTimeEnd,2),nSampleKernel);

%fill windows
for iFitsETR = 1:size(fitsTimeBeg,2)
    startWin = fitsTimeBeg(iFitsETR)-((nSampleKernel-1)/2);
    endWin = fitsTimeBeg(iFitsETR)+((nSampleKernel-1)/2);
    windowsBeg(iFitsETR,:) = startWin:1:endWin;
end

for iFitsETR = 1:size(fitsTimeEnd,2)
    startWin = fitsTimeEnd(iFitsETR)-((nSampleKernel-1)/2);
    endWin = fitsTimeEnd(iFitsETR)+((nSampleKernel-1)/2);
    windowsEnd(iFitsETR,:) = startWin:1:endWin;
end

%create mean to create new kernel
blinksETRbeg = NaN(size(windowsBeg,1),nSampleKernel);
for iBlink = 1:size(windowsBeg,1)
    blinksETRbeg(iBlink,:) = chanETR(windowsBeg(iBlink,:));
end
kernelETRbeg = mean(blinksETRbeg,1);

blinksETRend = NaN(size(windowsEnd,1),nSampleKernel);
for iBlink = 1:size(windowsEnd,1)
    blinksETRend(iBlink,:) = chanETR(windowsEnd(iBlink,:));
end
kernelETRend = mean(blinksETRend,1);


% figure();
figure()
col = lines(length(blinksETRend));

for iBlink = 1:size(windowsEnd,1)
    plot(blinksETRend(iBlink,:),'-','Color',col(iBlink,:),'LineWidth',0.2);
    hold on
end

figure()
plot(kernelETRbeg)
hold on
plot(kernelETRend); hold off

%% Convolve with means

nSamples = 101;
peakETRbeg = find(kernelETRbeg==max(kernelETRbeg));
ETRwindowBeg = (peakETRbeg-((nSamples-1)/2)):(peakETRbeg+((nSamples-1)/2));
blinkKernelBeg = kernelETRbeg(ETRwindowBeg);
blinkKernelBeg = (blinkKernelBeg-mean(blinkKernelBeg));
blinkKernelBeg = fliplr(blinkKernelBeg);

peakETRend = find(kernelETRend==max(kernelETRend));
ETRwindowEnd = (peakETRend-((nSamples-1)/2)):(peakETRend+((nSamples-1)/2));
blinkKernelEnd = kernelETRend(ETRwindowEnd);
blinkKernelEnd = (blinkKernelEnd-mean(blinkKernelEnd));
blinkKernelEnd = fliplr(blinkKernelEnd);

figure()
plot(blinkKernelBeg);
hold on;
plot(blinkKernelEnd);

%% Find blinks based on mean blink kernel

%convolve ETR data with Sample blink
convKernelBeg = conv(chanETR,blinkKernelBeg,'same');
convKernelEnd = conv(chanETR,blinkKernelEnd,'same');

%extract samples of eyetracker data to create mean blink for kernel
[~,fitsTimeBeg] = findpeaks(convKernelBeg,'MinPeakHeight',500,...
                  'MinPeakDistance',100);
fitsTimeBeg = fitsTimeBeg(2:end-1);

[~,fitsTimeEnd] = findpeaks(convKernelEnd,'MinPeakHeight',500,...
                  'MinPeakDistance',100);
fitsTimeEnd = fitsTimeEnd(2:end-1);

%define window
nSampleKernel = 151;
windowsBeg = NaN(size(fitsTimeBeg,2),nSampleKernel);
windowsEnd = NaN(size(fitsTimeEnd,2),nSampleKernel);

%fill windows
for iFitsETR = 1:size(fitsTimeBeg,2)
    startWin = fitsTimeBeg(iFitsETR)-((nSampleKernel-1)/2);
    endWin = fitsTimeBeg(iFitsETR)+((nSampleKernel-1)/2);
    windowsBeg(iFitsETR,:) = startWin:1:endWin;
end

for iFitsETR = 1:size(fitsTimeEnd,2)
    startWin = fitsTimeEnd(iFitsETR)-((nSampleKernel-1)/2);
    endWin = fitsTimeEnd(iFitsETR)+((nSampleKernel-1)/2);
    windowsEnd(iFitsETR,:) = startWin:1:endWin;
end

%create mean to create new kernel
blinksETRbeg = NaN(size(windowsBeg,1),nSampleKernel);
for iBlink = 1:size(windowsBeg,1)
    blinksETRbeg(iBlink,:) = chanETR(windowsBeg(iBlink,:));
end

blinksETRend = NaN(size(windowsEnd,1),nSampleKernel);
for iBlink = 1:size(windowsEnd,1)
    blinksETRend(iBlink,:) = chanETR(windowsEnd(iBlink,:));
end

figure();
col = lines(length(blinksETRend));
% yyaxis left
for iBlink = 1:size(windowsEnd,1)
    plot(blinksETRend(iBlink,:),'-','Color',col(iBlink,:),'LineWidth',0.2);
    hold on
end
figure();
col = lines(length(blinksETRbeg));
% yyaxis left
for iBlink = 1:size(windowsBeg,1)
    plot(blinksETRbeg(iBlink,:),'-','Color',col(iBlink,:),'LineWidth',0.2);
    hold on
end
figure();
% yyaxis left
plot(convSampleBeg);
xlim([0 100000])
hold on
% yyaxis right
plot(chanETR);
% 

%% find blink intervals

complete = [size(blinksETRbeg,1) size(blinksETRend,1)];
maxComplete = max(complete);
blinksComplete = zeros(size(fitsTimeBeg,2),2);
nextBlinkClose = false;

for iBlink = 1:(size(blinksComplete,1)-1)
    val = fitsTimeBeg(iBlink);
    larger = fitsTimeEnd > val;
    largerVal = fitsTimeEnd(larger);
    idx = find(min(largerVal-val));
    timeEnd = largerVal(idx);
    if fitsTimeBeg(iBlink+1) < timeEnd
        blinksComplete(iBlink,1) = fitsTimeBeg(1,iBlink);
        blinksComplete(iBlink,2) = NaN;
    else 
        blinksComplete(iBlink,1) = fitsTimeBeg(1,iBlink);
        blinksComplete(iBlink,2) = timeEnd;
    end
end

blinksComplete(any(isnan(blinksComplete),2),:) = [];
blinksLength = blinksComplete(:,2)-...
            blinksComplete(:,1);

avgBlink = mean(blinksLength);
stdBlink = std(blinksLength);

for iBlink = 1:length(blinksLength)
    confMin = avgBlink - (stdBlink * 1.65); % 90% Konfidenz Intervall
    confMax = avgBlink + (stdBlink * 1.65);
    if blinksLength(iBlink) < confMin
        blinksComplete(iBlink,:) = NaN;
    elseif blinksLength(iBlink) > confMax
        blinksComplete(iBlink,:) = NaN;
    end
end

blinksComplete(any(isnan(blinksComplete),2),:) = [];

for iBlink = 2:(size(blinksComplete,1)-1)
    if blinksComplete(iBlink+1,1)-blinksComplete(iBlink,2)<300
        blinksComplete(iBlink,1) = fitsTimeBeg(1,iBlink);
        blinksComplete(iBlink,2) = NaN;
    elseif blinksComplete(iBlink,1)-blinksComplete(iBlink-1,2)<300
        blinksComplete(iBlink,1) = fitsTimeBeg(1,iBlink);
        blinksComplete(iBlink,2) = NaN;
    end
end

blinksComplete(any(isnan(blinksComplete),2),:) = [];


lengthEEG = nSampleKernel*2;
windowsEEG = NaN(size(blinksComplete,1),lengthEEG+1);

for iFitsEEG = 1:size(blinksComplete,1)
    blinkMean = round(mean(blinksComplete(iFitsEEG,:)));
    startWin = blinkMean - (lengthEEG/2)+1;
    endWin = blinkMean + (lengthEEG/2)+1;
    windowsEEG(iFitsEEG,:) = startWin:1:endWin;
end

%% extract EOG data around mean of interval

%extract EEG Data
chanEEG = data.trial{1,1}(1,:);
blinksEEG = NaN(size(windowsEEG,1)-1,size(windowsEEG,2));

for iBlink = 1:(size(windowsEEG,1)-1)
    blinksEEG(iBlink,:) = chanEEG(windowsEEG(iBlink,:));
    blinksEEG(iBlink,:) = blinksEEG(iBlink,:) - mean(blinksEEG(iBlink,:),2);
end

meanEEG = mean(blinksEEG,1);


% %% extract MEG data around mean of interval
% 
% cfg.dataset = '1_ESI-HMgammaRepSpecif_20180601_01.ds';
% cfg.channel = {'MLF12','MLF11','MZF01','MRF11','MRF12'};
% cfg.continuous = 'yes';
% cfg.preproc.demean = 'yes';
% % cfg.lpfilter = 'yes';
% % cfg.lpfreq = 20;
% dataMEG = ft_preprocessing(cfg);
% 
% %extract EEG Data
% nChan = 1;
% chanLabels = {dataMEG.label};
% channel = 1:5;
% 
% for iChannel = 1:size(channel,2)
%     chanMEG = dataMEG.trial{1,1}(nChan,:);
%     name = chanLabels{1,1}(nChan);
%     name = name{1};
%     blinksMEG.(name) = NaN(size(windowsEEG,1)-1,size(windowsEEG,2));
%     
%     for iBlink = 1:(size(windowsEEG,1)-1)
%         blinksMEG.(name)(iBlink,:) = chanMEG(windowsEEG(iBlink,:));
%     end
%     
%     meanMEG.(name) = mean(blinksMEG.(name),1);
%     meanMEG.(name) = meanMEG.(name) - mean(meanMEG.(name),2);
%     
%     nChan = nChan+1;
% end
% 

%% plot results
xEEG = lengthEEG/2-lengthEEG:lengthEEG/2;
figure()
col = lines(length(blinksEEG));
for iBlink = 1:(size(windowsEEG,1)-1)
    plot(xEEG,blinksEEG(iBlink,:),'-','Color',col(iBlink,:),'LineWidth',0.2);
    hold on
end
ylabel('Power')
xlabel('Samples')
hold on;
plot(xEEG,meanEEG,'Color','k','LineWidth',1.5)
hold on;
[~,peakloc] = (max(meanEEG));
peakloc = peakloc - lengthEEG/2;
line([peakloc peakloc], get(gca, 'ylim'), 'Color','k')
hold on
line([-20 -20], get(gca, 'ylim'),'Color','r')

figure()
xlim([-302 302])
yyaxis left
col = lines(length(channel));
nChan = 1;
for iChannel = 1:size(channel,2)
    name = chanLabels{1,1}(nChan);
    name = name{1};
    plot(xEEG,meanMEG.(name),'-','Color',col(iChannel,:),'LineWidth',0.2);
    hold on
    nChan = nChan+1;
end
legend('MLF11','MLF12','MRF11','MRF12','MZF01')
hold on
yyaxis right
ylim([-0.0056 -0.00495])
plot(xEEG,meanEEG,'Color','k','LineWidth',1.5)
hold on;
[~,peakloc] = (max(meanEEG));
peakloc = peakloc - lengthEEG/2;
line([peakloc peakloc], get(gca,'ylim'), 'Color','k')
