% inspect head movement rough script

addpath /mnt/hpx/opt/fieldtrip_github;
ft_defaults;

cd('/mnt/gs/projects/HMgammaRepSpecif/Data/004/');

%define trials
cfg                         = [];
cfg.dataset                 = '4_ESI-HMgammaRepSpecif_20180612_02.ds';
cfg.trialdef.eventtype      = 'UPPT001';
cfg.trialdef.eventvalue     = 120;

cfg = ft_definetrial(cfg);

%read in location of head coils
cfg.channel                 = {'HLC0011','HLC0012','HLC0013', ...
                              'HLC0021','HLC0022','HLC0023', ...
                              'HLC0031','HLC0032','HLC0033'};
 
headpos = ft_preprocessing(cfg);

% calculate the mean coil position per trial
ntrials = length(headpos.sampleinfo);

%preallocate space
coil1 = NaN(3, ntrials);
coil2 = NaN(3, ntrials);
coil3 = NaN(3, ntrials);

%calculates mean x,y,z position of each of the three headcoils during each
%trial
for t = 1:ntrials
coil1(:,t) = [mean(headpos.trial{1,t}(1,:)); ...
              mean(headpos.trial{1,t}(2,:)); ...
              mean(headpos.trial{1,t}(3,:))];
coil2(:,t) = [mean(headpos.trial{1,t}(4,:)); ...
              mean(headpos.trial{1,t}(5,:)); ...
              mean(headpos.trial{1,t}(6,:))];
coil3(:,t) = [mean(headpos.trial{1,t}(7,:)); ...
              mean(headpos.trial{1,t}(8,:)); ...
              mean(headpos.trial{1,t}(9,:))];
end

%% 2D Plots

%calculate the headposition and orientation per trial
%needs function circumcenter.m
cc = circumcenter(coil1, coil2, coil3);

%creates matrix with change relative to first head position
cc_rel = [cc - repmat(cc(:,1),1,size(cc,2))]';
 
% plot translations
figure(); 
movement_plot = plot(cc_rel(:,1:3)*1000);% in mm
legend ('x coordinates','y coordinates','z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('head movements along the x,y,z axis');
xlabel('number of trials')
ylabel('head movement in mm')
movement_plot(1).Color = [0.2 0.8 0.8];
movement_plot(2).Color = [0 0.5 1];
movement_plot(3).Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
 
% plot rotations
figure(); 
p = plot(cc_rel(:,4:6));
legend ('x coordinates','y coordinates','z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('orientations to the x,y,z axis');
xlabel('number of trials')
ylabel('head orientation in degree')
p(1).Color = [0.2 0.8 0.8];
p(2).Color = [0 0.5 1];
p(3).Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);

%plot with subplots
figure();

subplot (2,1,1)
hold on
p = plot(cc_rel(:,3)*1000);% in mm
legend ('z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('Head Movements along the z Axis');
xlabel('Number of Trials')
ylabel('Movement in mm')
p.Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
hold on

subplot (2,1,2)
hold on
p = plot(cc_rel(:,6));
legend ('z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('Orientations to the z Axis');
ylabel('Orientation Change in degree')
xlabel('Number of Trials')
p.Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
hold on

% head movements 
maxposchange = max(abs(cc_rel(:,1:3)*1000)) % in mm

% print(gcf, 'movement_plot.png', '-dpng', '-r600')




%% 2D Coil Movement


coil1_rel = [coil1 - repmat(coil1(:,1),1,size(coil1,2))]';
coil2_rel = [coil2 - repmat(coil2(:,1),1,size(coil2,2))]';
coil3_rel = [coil3 - repmat(coil3(:,1),1,size(coil3,2))]';

%plot with subplots
figure();

subplot (3,1,1)
hold on
p = plot(coil1_rel*1000);% in mm
legend ('x coordinates','y coordinates','z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('Nasion');
xlabel('Number of Trials')
ylabel('Movement in mm')
ylim([-10 5])
p(1).Color = [0.2 0.8 0.8];
p(2).Color = [0 0.5 1];
p(3).Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
hold on

subplot (3,1,2)
hold on
p = plot(coil2_rel*1000);% in mm
legend ('x coordinates','y coordinates','z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('Left Ear');
xlabel('Number of Trials')
ylabel('Movement in mm')
ylim([-10 5])
p(1).Color = [0.2 0.8 0.8];
p(2).Color = [0 0.5 1];
p(3).Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
hold on

subplot (3,1,3)
hold on
p = plot(coil3_rel*1000);% in mm
legend ('x coordinates','y coordinates','z coordinates',...
        'Location', 'southwest');
legend ('boxoff');
clear xlabel;
clear ylabel;
title('Right Ear');
xlabel('Number of Trials')
ylabel('Movement in mm')
ylim([-10 5])
p(1).Color = [0.2 0.8 0.8];
p(2).Color = [0 0.5 1];
p(3).Color = [1 0.2 0.2];
hold on;
line([98 98], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([196 196], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([295 295], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([393 393], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
line([491 491], get(gca, 'ylim'), 'Color', [0.7 0.7 0.7]);
hold on


%% 3D Plots

%append rows
coord = cat(2,coil1,coil2,coil3);
xcoord = coord(1,:);
ycoord = coord(2,:);
zcoord = coord(3,:);

%time variable for color
time = 1:1:ntrials;

%values relative to start position
coil1_rel = [coil1 - repmat(coil1(:,1),1,size(coil1,2))];
coil2_rel = [coil2 - repmat(coil2(:,1),1,size(coil2,2))];
coil3_rel = [coil3 - repmat(coil3(:,1),1,size(coil3,2))];


%plot coordinates without time dimension
figure()

subplot(2,2,1);
scatter3(coil2_rel(1,:)*1000,coil2_rel(2,:)*1000,coil2_rel(3,:)*1000,5,time);
colormap (jet(7));
colorbar('Direction','reverse');
title('left ear'); xlabel('x'); ylabel('y'); zlabel('z movements in mm');
xlim([-3 3]); ylim([-3 3]); zlim([-10 3]);
az = 160; el = 15; view(az, el);
hold on

subplot(2,2,2);
scatter3(coil3_rel(1,:)*1000,coil3_rel(2,:)*1000,coil3_rel(3,:)*1000,5,time);
colormap (jet(7));
colorbar('Direction','reverse');
title('right ear'); xlabel('x'); ylabel('y'); zlabel('z movements')
xlim([-3 3]); ylim([-3 3])
zlim([-10 3])
az = 160;
el = 15;
view(az, el);
hold on

subplot(2,2,3);
scatter3(coil1_rel(1,:)*1000,coil1_rel(2,:)*1000,coil1_rel(3,:)*1000,5,time);
colormap (jet(7));
colorbar('Direction','reverse');
title('nasion')
xlabel('x')
ylabel('y')
zlabel('z movements')
xlim([-3 3])
ylim([-3 3])
zlim([-10 3])
az = 160;
el = 15;
view(az, el);
hold on

%3D center
subplot(2,2,4)
scatter3(cc_rel(:,1)*1000,cc_rel(:,2)*1000,cc_rel(:,3)*1000,5,time);
colormap (jet(7));
colorbar('Direction','reverse');
title('head center')
xlabel('x')
ylabel('y')
zlabel('z movements in mm')
xlim([-3 3])
ylim([-3 3])
zlim([-10 3])
az = 160;
el = 15;
view(az, el);
hold on
