function [ trl, event ] = trialfun_full( cfg )
%GAMMA_TRIALFUN Trial definition for the gammaRepSpecif dataset.
%
% Trigger codes used:
% 80        Baseline on
% 40        Stimulus on
% 120       Task change
% 160       Reaction
% 200       Stimulus off

trig.stimOn = 40;
trig.baseOn = 80;
trig.task = 120;
trig.react = 160;
trig.stimOff = 200;

% trig.stimOn = 104;
% trig.baseOn = 112;
% trig.task = 120;
% trig.react = 224;
% trig.stimOff = 232;

header = ft_read_header(cfg.dataset);
event = ft_read_event(cfg.dataset);

% determine the minimum number of samples before and after the stim trigger
min_sample =  round(cfg.trialdef.min_length * header.Fs);

% search for trigger events
triggernumber = length([event(strcmp('UPPT001', {event.type})).value]);
triggers = zeros(triggernumber, 2);

triggers(:,1) = [event(strcmp('UPPT001', {event.type})).value]'; %get trigger codes
triggers(:,2) = [event(strcmp('UPPT001', {event.type})).sample]'; %get trigger samples

% Check if we have no valid trials
stim_on = (triggers(:,1) == trig.stimOn);
stim_off = (triggers(:,1) == trig.task);

% if there are no valid trials, return an empty trl
if ~any(stim_on) || ~any(stim_off)
    trl = [];
    warning('Empty dataset, no trials found.');
    return
end

% get all the baseline onsets, find their stim presentation and trial end
trl = [];
include = true; %should this trial be included?
iAll = 0; %count the trials

for iTrigger=1:length(triggers)
    include = true; % should this trial be included? reset.
    if triggers(iTrigger,1) == trig.baseOn % is this a baseline begin trigger?
        basebegin = triggers(iTrigger,2);
        
        % Search for the next stimulus On trigger
        stim_found = false;
        trigger_gap = 1;
        while stim_found == false % find the next stimulus on trigger
            if trigger_gap > 3 || iTrigger+trigger_gap > length(triggers)
                fprintf('No reasonably close stim found for trial %d.\n',iAll+1)
                include = false; % don't include this trial, as it has no stim trigger
                stim_found = true; % don't continue searching
            elseif triggers(iTrigger+trigger_gap,1) == trig.stimOn
                trlbegin = triggers(iTrigger+trigger_gap,2); % set trial start sample
                stim_found = true;
            end
            trigger_gap = trigger_gap +1;
        end
        
        % Search fo the next end of trial (task on or stim off) trigger
        trialend_found = false;
        trigger_gap = 1;
        while trialend_found == false % find the next trial ending
            if trigger_gap > 3 || iTrigger+trigger_gap > length(triggers)
                fprintf('No reasonably close trial end found for trial %d.\n',iAll+1)
                include = false; % don't include this trial, as it has no end trigger
                trialend_found = true; % don't continue searching
            elseif triggers(iTrigger+trigger_gap,1) == trig.task || ...
                   triggers(iTrigger+trigger_gap,1) == trig.stimOff
                trlend = triggers(iTrigger+trigger_gap,2); % set trail end sample
                trialend_found = true;
            end
            trigger_gap = trigger_gap +1;
        end
        offset = basebegin - trlbegin; % how many pre-stimulus samples
        iAll = iAll+1;
        triallength = trlend-trlbegin;
        
        % check whether stimulus has minimal trial length, discard if otherwise
        if triallength >= min_sample && include == true
            %trlend = triggers(iTrigger,2) + posttrig-1;
            % bring it all together
            begin_corr = basebegin + cfg.stim_on_delay;
            end_corr = trlend + cfg.stim_off_delay;
            newtrl = [begin_corr, end_corr, offset, iAll];
            trl = [trl; newtrl]; % and attach it to the trl
        end % add the trial, if it is long enough
    end %if this is a trial
end %for

end %function