#!/home/stauchb/.conda/envs/powerspect/bin/python
"""
A function callable from terminal that applies FOOOF to a temporarily saved
psd in the range of the first input and returns the fit gamma peak frequency.
Expects psd and freq to be saved as v7 .mat files in the same folder with 
filenames temp_psd and temp_freq.

Terminal arguments:
    - Subject number as string (eg '001') for plot naming
    - Lower gamma range border
    - Upper gamma range border

"""

import sys
import os
from fooof import FOOOF
import numpy as np

class NullWriter(object):
    # A class to not write output, needed to suppress FOOOF output.
    def write(self, arg):
        pass


if __name__ == "__main__":
    # main
    subj_nr = sys.argv[1]
    range_low = int(sys.argv[2])
    range_high = int(sys.argv[3])
    
    basepath = os.path.abspath(os.path.dirname(sys.argv[0]))
    freq = basepath + '/temp_freq.csv'
    psd = basepath + '/temp_psd.csv'
    outpath = basepath + '/' + 'gamma_'+ subj_nr +'.csv'
    
    # Load in the temporary data files saved by Matlab.
    freq = np.genfromtxt(freq)
    psd = np.genfromtxt(psd)
    
    # Suppress output
    nullwriter = NullWriter()
    old_stdout = sys.stdout
    sys.stdout = nullwriter

    fm = FOOOF(peak_width_limits = [3, 40], aperiodic_mode = 'fixed')
    freq_range = [range_low, range_high]
    fm.fit(freq, psd, freq_range)
    fm.report()
    fm.save_report(file_name = subj_nr, file_path = '/mnt/cs/projects/HMgammaColorSurf/Analysis/Plots/Gamma_Peak_Fits/')
    
    fitted_peaks = fm.peak_params_ # Get peak frequency, amplitude, and bandwidth
    
    # Check if no peak was found, if yes, print silly value.
    if fitted_peaks.size == 0:
        sys.stdout = old_stdout
        print(999)
        sys.exit()
                
    # write results to disc to be picked up by matlab
    np.savetxt(outpath, fitted_peaks, delimiter = ',')
    # If there are two valid gamma peaks, select the much bigger one. If they 
    # are similar in amplitude, select the one closer to 55Hz.
    if fitted_peaks.size > 3:
        i_max_amp = np.argmax(fitted_peaks[:,1])
        fitted_peaks = fitted_peaks[i_max_amp,:]
        # Check if the higher one is 1.3 times as high as the lower one, if yes:
        # pick it.
        #if fitted_peaks[i_max_amp,1] >= 1.3*fitted_peaks[1-i_max_amp,1]:
        #    fitted_peaks = fitted_peaks[i_max_amp,:]
            
        #else: # Pick the one closer to 50 Hz.
        #    diff_to_mid = np.abs(50-fitted_peaks[:,0])
        #    closer_to_mid = np.argmin(diff_to_mid)
        #    fitted_peaks = fitted_peaks[closer_to_mid,:]
    
    # Check if no peak was found, if yes, print silly value.
    if fitted_peaks.size == 0:
        sys.stdout = old_stdout
        print(999)
        sys.exit()

    elif fitted_peaks.shape[0] == 1: 
        # Return output
        fOut = fitted_peaks[0,0]
        # Return output
        sys.stdout = old_stdout
        print(fOut)

    else:
        # Return output
        fOut = fitted_peaks[0]
        # Return output
        sys.stdout = old_stdout
        print(fOut)

    
else:
    def run(subj_nr, range_low, range_high):
        basepath = os.path.dirname(os.path.abspath(__file__))
        freq = basepath + '/temp_freq.csv'
        psd = basepath + '/temp_psd.csv'
   
        # Load in the temporary data files saved by Matlab.
        freq = np.genfromtxt(freq)
        psd = np.genfromtxt(psd)      

        fm = FOOOF(peak_width_limits = [3, 40], background_mode = 'fixed')
        freq_range = [range_low, range_high]
        fm.fit(freq, psd, freq_range)
        fm.save_report(file_name = subj_nr, 
                       file_path = '/mnt/cs/projects/HMgammaColorSurf/' +
                       'Analysis/Plots/Gamma_Peak_Fits/')
        
        fitted_peaks = fm.peak_params_ # Get peak frequency, amplitude, and bandwidth
    
    # Check if no peak was found, if yes, print silly value.
        if fitted_peaks.size == 0:
            fOut = 999
        
        else:                       
    
            # If there are two valid gamma peaks, select the much bigger one. If they 
            # are similar in amplitude, select the one closer to 55Hz.
            if fitted_peaks.size > 3:
                i_max_amp = np.argmax(fitted_peaks[:,1])
                fitted_peaks = fitted_peaks[i_max_amp,:]
                # Check if the higher one is 1.3 times as high as the lower one, if yes:
                # pick it.
                #if fitted_peaks[i_max_amp,1] >= 1.3*fitted_peaks[1-i_max_amp,1]:
                #    fitted_peaks = fitted_peaks[i_max_amp,:]
            
            #else: # Pick the one closer to 50 Hz.
            #    diff_to_mid = np.abs(50-fitted_peaks[:,0])
            #    closer_to_mid = np.argmin(diff_to_mid)
            #    fitted_peaks = fitted_peaks[closer_to_mid,:]
    
        # Check if no peak was found, if yes, print silly value.
        if fitted_peaks.size == 0:
            sys.stdout = old_stdout
            print(999)
            sys.exit()

        elif fitted_peaks.shape[0] == 1: 
            # Return output
            fOut = fitted_peaks[0,0]
            # Return output
            sys.stdout = old_stdout
            print(fOut)

        else:
            # Return output
            fOut = fitted_peaks[0]
            # Return output
            sys.stdout = old_stdout
            print(fOut)

