#!/home/stauchb/.conda/envs/powerspect/bin/python
"""
A function callable from terminal that applies FOOOF to a temporarily saved
psd in the range of the first input and returns the fit gamma peak frequency.
Expects psd and freq to be saved as v7 .mat files in the same folder with 
filenames temp_psd and temp_freq.

Terminal arguments:
    - Subject number as string (eg '001') for plot naming
	- The frequency band we're looking for, can be 'theta',
	  'alpha', or 'beta'

"""

import sys
import os
from fooof import FOOOF
import numpy as np
import matplotlib

class NullWriter(object):
    # A class to not write output, needed to suppress FOOOF output.
    def write(self, arg):
        pass

# main
subj_nr = sys.argv[1]
freq_band = sys.argv[2]

if freq_band == 'alpha':
    freq_prior = 10 # taken from literature
    freq_range = [7, 13]
elif freq_band == 'theta':
    freq_prior = 6 # taken from literature, mean([4,8])
    freq_range = [3, 9]
elif freq_band == 'beta':
    freq_prior = 20 # taken from average spectra
    freq_range = [13, 30]
else:
    print('Invalid frequency band')
    sys.exit()

basepath = os.path.abspath(os.path.dirname(sys.argv[0]))
freq = basepath + '/temp_freq.csv'
psd = basepath + '/temp_psd.csv'
plotpath = basepath + '/' + freq_band + '_' + subj_nr + '.png'

# Load in the temporary data files saved by Matlab.
freq = np.genfromtxt(freq)
psd = np.genfromtxt(psd)

# Suppress output
nullwriter = NullWriter()
old_stdout = sys.stdout
sys.stdout = nullwriter

fm = FOOOF(max_n_peaks = 2)
fm.fit(freq, psd, freq_range)
fm.plot()
matplotlib.pyplot.savefig(plotpath, format = 'png', dpi = 400)

fitted_peaks = fm.peak_params_ # Get peak frequency, amplitude, and bandwidth

# Check if no peak was found, if yes, print silly value.
if fitted_peaks.size == 0:
    sys.stdout = old_stdout
    print(999)
    sys.exit()


# If there are two valid peaks, select the much bigger one. If they 
# are similar in amplitude, select the one closer to freq_prior.
if fitted_peaks.size > 3:
    i_max_amp = np.argmax(fitted_peaks[:,1])
    
    # Check if the higher one is 1.3 times as high as the lower one, if yes:
    # pick it.
    if fitted_peaks[i_max_amp,1] >= 1.3*fitted_peaks[1-i_max_amp,1]:
        fitted_peaks = fitted_peaks[i_max_amp,:]
    
    else: # Pick the one closer to freq_prior Hz.
        diff_to_mid = np.abs(freq_prior-fitted_peaks[:,0])
        closer_to_mid = np.argmin(diff_to_mid)
        fitted_peaks = fitted_peaks[closer_to_mid,:]

# Check if no peak was found, if yes, print silly value.
if fitted_peaks.size == 0:
    sys.stdout = old_stdout
    print(freq_prior)
    sys.exit()

elif fitted_peaks.shape[0] == 1: 
    # Return output
    fOut = fitted_peaks[0,0]
    # Return output
    sys.stdout = old_stdout
    print(fOut)

else:
    # Return output
    fOut = fitted_peaks[0]
    # Return output
    sys.stdout = old_stdout
    print(fOut)