function [handles] = gamma_retinotopy_plot(cfg, atlas, sourcevals, areas)
% GAMMA_RETINOTOPY_PLOT Plots gamma power according to retinotopic position
% in requested brain areas.
% Cfg is the group_cfg-parameter of the GroupAnalysis object, sourcevals is
% a vector of gamma power increase per each 32k fs_LR vertex in percent, 
% areas is a cell of strings with the requested area names.
%
% h is handle of plot
% hb is hande of color bar

% Load in retinotopy information aligned to 32k fs_LR
eccentFull = ft_read_cifti(cfg.hcp.eccent, ...
    'mapname', 'array', 'readdata', true);
polAngFull = ft_read_cifti(cfg.hcp.polAng, ...
    'mapname', 'array', 'readdata', true);

% Only take left and right cortex
eccentFull = eccentFull.fit1_eccentricity_msmall(...
    eccentFull.brainstructure <3);
polAngFull = polAngFull.fit1_polarangle_msmall(...
    polAngFull.brainstructure <3);

minPow = 95;
maxPow = 270;
% one plot per requested area
for iArea = 1:length(areas)
    subplot(1, length(areas), iArea);
    thisArea = areas{iArea};
    roi = label_HCP_areas([], atlas, thisArea);
    eccent = eccentFull(~strcmp(roi, 'none'));
    polAng = polAngFull(~strcmp(roi, 'none'));
    power = sourcevals(~strcmp(roi, 'none'));
    polAng = deg2rad(polAng);
    xcoord = eccent .*sin(0.5*pi-polAng)/sin(pi/2);
    ycoord = eccent .*sin(polAng)/sin(pi/2);

    r = 0:1:12;
    theta = deg2rad(0:15:360)-pi;
    X = r'*cos(theta);
    Y = r'*sin(theta);
    recepGamma = scatteredInterpolant(xcoord, ycoord, power);
    C = recepGamma(X,Y);
    h = pcolor(X,Y,C);
    h.FaceColor = 'flat';
    h.EdgeColor = 'none';
    daspect([1 1 1])
    %caxis(gca, [minPow, maxPow]);

    %title(sprintf(...
    %    'Induced retinotopic gamma, %s', thisArea))
    xlabel('H-deviation from fovea (deg)')
    ylabel('V-deviation from fovea (deg)')
    
    handles.h1 = h;
end


end

