function [stims, stimtypes, stimRep] = getColoredStimtypes(behavior)
%getColoredStimtypes Takes in the behavior table from HMgammaColorSurf,
% returns a per-trial vector of stimulus types and a vector of unique
% stimtypes. In addition, stimRep is the per-trial repetition number (ie
% the nth repetition of a given stimulus during this trial).

stims = behavior.stimType;
stims(behavior.block == 3) = {'contrast'};

if all(behavior.colorR <= 1 | isnan(behavior.colorR)) && ...
        all(behavior.colorG <= 1 | isnan(behavior.colorG)) && ...
        all(behavior.colorB <= 1 | isnan(behavior.colorB))
    warning('Resetting RGB values to 0-255 range.')
    behavior.colorR = behavior.colorR.*255;
    behavior.colorG = behavior.colorG.*255;
    behavior.colorB = behavior.colorB.*255;
end


colors = strcat(...
    num2str(behavior.colorR, '%03.0f'), '_',...
    num2str(behavior.colorG, '%03.0f'), '_', ...
    num2str(behavior.colorB, '%03.0f'));
colors = cellstr(colors);
stims(strcmp(stims, 'color')) = colors(strcmp(stims, 'color'));
stimtypes = unique(stims);

% Count the per-trial repetition number of the stimulus presented in that
% trial.
nRep = zeros(size(stimtypes));
stimRep = zeros(size(stims));
for iTrial = 1:length(stims)
    iStim = ismember(stimtypes, stims{iTrial});
    nRep(iStim) = nRep(iStim) + 1;
    stimRep(iTrial) = nRep(iStim);
end

end

