function [ stimtypes, stimtype, orientations, stimclass ] = getStimtypes( behav_results )
% GETSTIMTYPES Utility function that extracts a cell of all presented
% stimuli and their orientation from behavioral data. 
% Input:
% behav_results = A standardized experiment results table, as created by eg
%                 the RepUp Paradigm library during the experiment.
% Output:
% stimtypes     = A cell of the unique stimulus types, in order of their
%                 appearence.
% stimtype      = The stimulus type of each trial, in order of the trials.
% orientations  = The stimulus orientations of the unique stimulus types, in 
%                 order of their appearence.
% stimclass     = Class of the stimulus that was shown. Can be "color",
%                 "grating" or "contrast"

stimtype = cell(1, length(behav_results.trialNr));
stimclass = stimtype;

for iTrial = 1:length(behav_results.trialNr)
    stimtype{iTrial} = [behav_results.stimType{iTrial} ' '...
        num2str(behav_results.orientation(iTrial)) ' '...
        num2str(behav_results.colorR(iTrial),'%03.f') ' '...
        num2str(behav_results.colorG(iTrial),'%03.f') ' '...
        num2str(behav_results.colorB(iTrial),'%03.f')];
    stimclass{iTrial} = behav_results.stimType{iTrial};
    if iTrial > 540
       contrastWarning = true;
       stimtype{iTrial} = [stimtype{iTrial} ' contrast']; 
       stimclass{iTrial} = 'contrast';
    end
end
if any(exist('contrastWarning', 'var')) && contrastWarning
    warning('Assuming that all trials with trial nr. >540 are contrast trials.')
end

stimtypes = unique(stimtype, 'stable');
% extract numbers (i.e. the orientations) from the stimtype strings
orientations = regexp(stimtypes, '\d+\.*\d*', 'match'); 
orientations = cellfun(@str2double, orientations, 'UniformOutput', false);

end

