function [ isFolder ] = isfolder( folderName )
% If folderName is the path of an existing folder or in the current
% working directory, return 1. Otherwise, return 0.
% Several folders can be given as a cell of character vectors.
% folderName should be a relative path from the current folder
% or a full path.
%
% This is a compatibility function that should only be added to the path on
% MATLAB versions prior to 2017b.

% Workaround: attempt to cd to specified folder and back. If it works,
% it is a folder.
currentFolder = pwd;

switch class(folderName)
    case 'char'
        try
            cd(folderName)
            isFolder = 1;
        catch
            isFolder = 0;
        end
        cd(currentFolder);
        
    case 'cell'
        assert(any(size(folderName) == 1), 'Invalid folderName dimension.');
        
        for iFolder = 1:length(folderName)
            thisFolder = folderName{iFolder};
            try
                cd(thisFolder)
                isFolder(iFolder) = 1;
            catch
                isFolder(iFolder) = 0;
            end
            cd(currentFolder);
            
        end
    otherwise
        error('Invalid folderName - must be char or cell.')
end


end

