function [indicesL, indicesR] = reduce_HCP_surf(obj, factor)
% reduce_HCP_surf subsamples the fs_LR surface down to a requested part.
% Uses the spherical template to ensure even spacing on the surface, as
% reducepatch otherwise picks more vertices along more strongly curved
% areas.

if ~exist('factor', 'var') || isempty(factor)
    factor = 1/8;
end

% load templates, flip the right one for coherent patchreducing.
templateL = ft_read_headshape(obj.cfg.beam.hcp.sphere{1});
templateR = ft_read_headshape(obj.cfg.beam.hcp.sphere{2});
templateR.pos(:,1) = templateR.pos(:,1) * -1;
templateR.tri = fliplr(templateR.tri);

reducedL = reducepatch(templateL.tri, templateL.pos, factor);
reducedR = reducepatch(templateR.tri, templateR.pos, factor);

iL = ismember(templateL.pos, reducedL.vertices, 'rows');
iR = ismember(templateR.pos, reducedR.vertices, 'rows');
assert(all(iL == iR), ['Either the two L/R templates are not '...
    'symmetrical, or patchreduce is not reproducible.']);

indicesL = find(iL);
indicesR = find(iR) + length(iL);

end

