function [indices, labels] = select_HCP_parcel(which, atlas, hemisphere)
% select_HCP_parcel Returns all indices of vertices in the HCP atlas that
% belong to area(s) in the cell which. If hemisphere is 'both' (default), 
% vertices in both  hemisphere are given. Otherwise, only right hemisphere
% vertices (hemisphere = 'right') or left hemisphere vertices (= 'left') 
% are returned.

% set defaults
assert(nargin >= 2, 'Missing inputs')
if ~exist('hemisphere', 'var') || isempty(hemisphere)
    hemisphere = 'both';
end

if ~iscell(which) && ischar(which)
    which = {which};
end

HCPcolor = ...
    atlas.corticalareas_dil_final_final_areas_group_colors;
HCPlabel = ...
    atlas.corticalareas_dil_final_final_areas_group_colorslabel;

%% Parse str which, select fitting vertices
indices = {};
labels = {};
for iWhich = 1:length(which)
    switch hemisphere
        case 'both'
            target = ['_' which{iWhich} '_'];
        case 'right'
            target = ['R_' which{iWhich} '_'];
        case 'left'
            target = ['L_' which{iWhich} '_'];
        otherwise
            error('Invalid hemisphere selected')
    end
    
    fprintf('Selecting vertices from area %s.\n', target);
    targetAreas = find(contains(HCPlabel, target));
    indices{iWhich} = find(ismember(HCPcolor, targetAreas));
    labels{iWhich} = HCPlabel((HCPcolor(indices{iWhich})))';
end

indices = cat(1, indices{:});
labels = cat(1, labels{:});

end

