function [colorsOut, DKLout, LMSout] = stimtype2colors(...
    stimtypes, whichStims, RGBbackground, fixGamma)
%stimtypes2colors transforms a table of stimtypes (string labels) into the
%colors they should be plotted in. whichStims is an index vector that
%selects some of the available stimtypes. If you just want the color
%stimuli, set whichStims = 1:8. If fixGamma is true, the colors are
%de-linearized (plotted as they would look on the projector).

if ~exist('whichStims', 'var') || isempty(whichStims)
    whichStims = 1:length(stimtypes);
end

if ~exist('fixGamma', 'var') || isempty(fixGamma)
    fixGamma = false;
end

if ~exist('RGBbackground', 'var') || isempty(RGBbackground)
    RGBbackground = [102 102 102];
else
    warning('Make sure you give RGBbackground with range = [0 255]!')
end
lmsBackground = rgb2lms(RGBbackground./255);

for iStim = whichStims
    thisStim = stimtypes{iStim};
    switch thisStim
        case 'grating'
            iColor = [0 0 0];
            DKLout(iStim,:) = NaN(1,3);
            LMSout(iStim,:) = NaN(1,3);
        case 'contrast'
            iColor = [100 100 100];
            DKLout(iStim,:) = NaN(1,3);
            LMSout(iStim,:) = NaN(1,3);
        otherwise
            iColor = cellfun(@str2num, strsplit(thisStim, '_'));
            lmsStim = rgb2lms(iColor./255);
            DKLout(iStim,:) = lms2dkl(lmsStim, lmsBackground);
            LMSout(iStim,:) = lmsStim;
    end
    %iColor = gamCor(iColor);
    if fixGamma
        colorsOut(iStim,:) = lin2rgb(iColor./255);
    else
        colorsOut(iStim,:) = iColor./255;
    end
end

end