function trialBlockPlot(cfg, data, plot_what)
%trialBlockPlot Plot a quantity (such as gamma power, pupil size, accuracy,
% etc.) on a per-trial fashion, slightly smoothed within blocks (to
% simulate binning).
%
% Inputs
% cfg       a cfg-struct with the fields .demean (boolean), .zscore
%           (boolean) and .span (int).
% data      table of our per-trial results. Needs to hve a field .block
%           with block number, a field of the quility to be plotted, as
%           well as a .trialNr and a .subjNr field.
% plotWhat  Field name of the to-be-plotted quantity in the data table.

% Find block borders and colors
nBlocks = max(data.block);
iColors = lines(nBlocks);
blocks = zeros(nBlocks, 2);
for iBlock = 1:nBlocks
    blocks(iBlock, 1) = min(...
        data.trialNr(data.block == iBlock));
    blocks(iBlock, 2) = max(...
        data.trialNr(data.block == iBlock));
end
first = min(data.trialNr);
last = max(data.trialNr);

% Split according to subjects
data_cell = splitapply(@(x) {x}, data.(plot_what), ...
    findgroups(data.subjNr))';
trialnr_cell =  splitapply(@(x) {x}, data.trialNr, ...
    findgroups(data.subjNr))';

% Plot it
smoothedGroupLinePlot(trialnr_cell, data_cell, ...
    'fullX', first:last, ...
    'span', cfg.span, ...
    'blocks', blocks, ...
    'demean', cfg.demean, ...
    'zscore', cfg.zscore, ...
    'color', iColors);


end

