function [cfg, subject] = setup(subj_nr)
% SETUP Add necessary folders, create config and subject structures.

%pyversion('/home/stauchb/.conda/envs/powerspect/bin/python');
if iscell(subj_nr)
    assert(numel(subj_nr) == 1, 'setup() is for single subjects.');
    subj_nr = subj_nr{1};
end

addpath(genpath('/mnt/cs/projects/HMgammaColorSurf/Analysis'));
addpath /opt/ESIsoftware/matlab/slurmfun/
addpath /opt/ESIsoftware/matlab/esi-nbf/

basepath = '/mnt/hpx/projects/HMgammaColorSurf';

redoSubj = false; % toggle to be switched if subject struct generation code changes

% Load subject struct from disk, if it already exists. Otherwise create
% base version.
if exist(fullfile(basepath, 'Data', num2str(subj_nr, '%03d'), ...
        'Preprocessed', 'subject.mat'), 'file') && ~redoSubj
    ESIload(fullfile(basepath, 'Data', num2str(subj_nr, '%03d'), ...
        'Preprocessed', 'subject.mat'));
else
    subject = fillSubjectInfo(subj_nr, basepath);
    
    if ~exist(fullfile(basepath, 'Data', num2str(subj_nr, '%03d'),...
            'Preprocessed'), 'dir')
        mkdir(fullfile(basepath, 'Data', num2str(subj_nr, '%03d'),...
            'Preprocessed'));
    end
    ESIsave(fullfile(basepath, 'Data', num2str(subj_nr, '%03d'), ...
        'Preprocessed', 'subject.mat'), 'subject');
end

% Get current configuration
cfg = fillConfigs(subject, basepath);

if ~cfg.general.useGithub
    cfg.general.fieldtrip = '/mnt/cs/opt/fieldtrip_esi';
elseif cfg.general.useGithub
    cfg.general.fieldtrip = '/mnt/cs/opt/fieldtrip_github';
end

addpath(cfg.general.fieldtrip)
ft_defaults;
% suppress the 'correcting numerical inaccuracy in the time axes' warning
ft_warning off FieldTrip:ft_appenddata:ft_checkdata:ft_datatype_raw:fixtimeaxes:line284

end